<?php

namespace App\Console\Commands;

use App\Models\Permission;
use App\Models\PermissionGroup;
use App\Models\Role;
use Illuminate\Console\Command;
use Illuminate\Support\Facades\Route;

class InitializeRoutePermission extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'lpc:initialize-route-permission';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Initialize routing permissions';

    /**
     * Execute the console command.
     */
    public function handle()
    {
        $routes = Route::getRoutes();

        $permissionGroup = PermissionGroup::query()->firstOrCreate([
            'name' => 'default',
        ]);

        foreach ($routes as $route) {
            if (! $route->getName()) {
                continue;
            }

            Permission::query()->firstOrCreate([
                'name' => $route->getName(),
                'guard_name' => 'api',
            ], [
                'description' => $route->getName(),
                'permission_group_id' => $permissionGroup->id,
            ]);
        }

        $role = Role::query()->find(config("auth.super_admin_role_id"));
        $role?->syncPermissions(Permission::query()->pluck("name")->toArray());
    }
}
