<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Http\Requests\API\Asset\CreateOrUpdateRequest;
use App\Http\Resources\API\AssetResource;
use App\Models\Asset;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class AssetController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index(Request $request)
    {
        $name=$request->input("name");
        $groupId=$request->input("groupId");
        $assets=Asset::allowed()->where('name', 'like', "%{$name}%")
            ->when($groupId,function ($query,$groupId){
                return $query->where('group_id',$groupId);
            })
            ->get();
        //$assets = Asset::allowed()->filter($request->all())->get();

        return AssetResource::collection($assets);
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(CreateOrUpdateRequest $request)
    {
        Asset::create([
            ...$request->all(),
            'company_id' => Auth::user()->company_id,
            'whitelist' => $request->whitelist ? sprintf(",%s", implode(',', $request->whitelist)) : null,
            'created_by' => Auth::id(),
        ]);

        return $this->created();
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        $asset = Asset::allowed()->findOrFail($id);

        return new AssetResource($asset);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $asset = Asset::allowed()->findOrFail($id);

        $asset->update([
            ...$request->all(),
            'whitelist' => $request->whitelist ? sprintf(",%s", implode(',', $request->whitelist)) : null,
        ]);

        return $this->noContent();
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $asset = Asset::allowed()->findOrFail($id);

        $asset->delete();

        return $this->noContent();
    }
}
