<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Http\Requests\API\Plan\CreateOrUpdateRequest;
use App\Http\Resources\API\PlanResource;
use App\Models\Plan;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class PlanController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index(Request $request)
    {
        $plans = Plan::filter($request->all())->simplePaginate();

        return PlanResource::collection($plans);
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(CreateOrUpdateRequest $request)
    {
        $plan = new Plan();

        $plan->mergeFillable([
            'company_id'
        ]);

        $plan->fill([
            ...$request->all(),
            'company_id' => Auth::user()->company_id,
        ]);

        $plan->save();

        return $this->created();
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        $plan = Plan::findOrFail($id);

        return new PlanResource($plan);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(CreateOrUpdateRequest $request, string $id)
    {
        $plan = Plan::findOrFail($id);

        $plan->fill($request->all());

        $plan->save();

        return $this->noContent();
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $plan = Plan::findOrFail($id);

        $plan->delete();

        return $this->noContent();
    }
}
