<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Http\Requests\API\Requirement\CreateOrUpdateRequest;
use App\Http\Requests\API\Requirement\LinkPlanRequest;
use App\Http\Resources\API\AssetRequirementResource;
use App\Http\Resources\API\RequirementResource;
use App\Models\Plan;
use App\Models\Requirement;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class RequirementController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        //
    }

    public function byAsset(string $assetId)
    {
        $requirements = Requirement::query()
            ->with(['createdBy', 'plan'])
            ->where('asset_id', $assetId)
            ->simplePaginate();

        return AssetRequirementResource::collection($requirements);
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(CreateOrUpdateRequest $request)
    {
        $requirement = new Requirement();

        $requirement->mergeFillable([
            'company_id', 'created_by',
        ]);

        $requirement->fill([
            ...$request->all(),
            'company_id' => Auth::user()->company_id,
            'created_by' => Auth::id(),
        ]);
        $requirement->save();

        return $this->created();
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        $requirement = Requirement::query()->findOrFail($id);

        return new RequirementResource($requirement);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        //
    }

    public function linkPlan(LinkPlanRequest $request, string $planId)
    {
        $plan = Plan::query()->findOrFail($planId);

        Requirement::query()->where("asset_id", $plan->asset_id)
            ->whereIn('id', $request->get("requirement_ids"))
            ->update([
                'plan_id' => $plan->id,
            ]);

        return $this->noContent();
    }
}
